#
# spec file for package man-pages-ja
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           man-pages-ja
Version:        20230815
Release:        1.1
Summary:        LDP Manual Pages (Japanese)
License:        BSD-3-Clause AND GPL-2.0-only AND GFDL-1.1-only AND GFDL-1.2-only AND GFDL-1.3-only
Group:          Documentation/Man
Summary(ja):    Linux 日本語マニュアルページ
URL:            https://linuxjm.osdn.jp/download.html
Source:         https://linuxjm.osdn.jp/man-pages-ja-%{version}.tar.gz
# Some manpages are only shipped if the programs exist..
BuildRequires:  fdupes
Provides:       locale(man:ja)
BuildArch:      noarch

%description -l ja
このパッケージは linux のための日本語のマニュアルページを提供するものです。
日本語訳は英文より古い場合が多々ありますがご了承ください。

%description
These are the Japanese man pages of the Linux Documentation Project.
Note that they are normally older than the English versions.  For
reference, you should use the English versions.

%prep
%autosetup

%build

%install
mkdir -p %{buildroot}%{_mandir}/ja
# There are some duplicates.
# Adjust the following list of subdirectories
# so that the preferred versions of the man pages come
# last and thus overwrite the less good versions:
# especially:
# prefer LDP_man-pages over bind
# prefer LDP_man-pages over netkit
# prefer LDP_man-pages over ld.so
# prefer LDP_man-pages over shadow
# prefer gnumaniak over GNU_sh-utils
# prefer gnumaniak over GNU_textutils
# prefer gnumaniak over GNU_sh-utils
# prefer gnumaniak over GNU_fileutils
# prefer man-db over man
# prefer util-linux over SysVinit
# prefer util-linux over shadow
# prefer util-linux over procps
# prefer util-linux over netkit
# prefer nfs-utils over SysVinit
# prefer nfs-utils over nfs-server
# prefer netkit over wu-ftpd
# prefer ypbind over ypbind-mt
for dir in \
    shadow \
    GNU_automake \
    GNU_coreutils \
    gnumaniak \
    GNU_bash \
    GNU_bc \
    GNU_binutils \
    GNU_cpio \
    GNU_dejagnu \
    GNU_ed \
    GNU_fileutils \
    GNU_findutils \
    GNU_gawk \
    GNU_gcc \
    GNU_gdb \
    GNU_gdbm \
    GNU_grep \
    GNU_groff \
    GNU_gzip \
    GNU_indent \
    GNU_less \
    GNU_make \
    GNU_patch \
    GNU_rcs \
    GNU_screen \
    GNU_sed \
    GNU_sh-utils \
    GNU_sharutils \
    GNU_tar \
    GNU_texinfo \
    GNU_textutils \
    GNU_uucp \
    LDP_man-pages \
    SysVinit \
    acl \
    apmd \
    at \
    autofs \
    bind \
    bs \
    bsd-games \
    bsd-games-non-free \
    byacc \
    bzip2 \
    cdrecord \
    cron \
    cups \
    cvsup \
    dhcp \
    dhcp2 \
    dhcpcd \
    dump \
    ebtables \
    e2compr-ancillary \
    e2fsprogs \
    eject \
    expect \
    fdutils \
    fetchmail \
    file \
    flex \
    fort77 \
    glibc-linuxthreads \
    hdparm \
    ipchains \
    ipchains-scripts \
    ipfwadm \
    iptables \
    ld.so \
    lilo \
    lids \
    linux-man9 \
    lpr-linux \
    majordomo \
    man \
    man-db \
    microcode_ctl \
    mirrordir \
    module-init-tools \
    modutils \
    mpg123 \
    ncftp \
    ncurses \
    net-tools \
    netatalk \
    netkit \
    nfs-server \
    nfs-utils \
    pciutils \
    pcmcia-cs \
    ppp \
    procinfo \
    procps \
    psmisc \
    quota \
    rdate \
    reiserfsprogs \
    rp-pppoe \
    rpm \
    rssh \
    sendmail \
    setserial \
    smartmontools \
    sudo \
    sysklogd \
    tcp_wrappers \
    tcpdump \
    tcsh \
    ucd-snmp \
    util-linux \
    uudeview \
    vsftpd \
    wu-ftpd \
    xinetd \
    yp-tools \
    ypbind-mt \
    ypserv \
    ypbind \
    zebedee
do
	for i in `find ./manual/$dir/ -regex ".*/man./.+\.."`
	do
	    SUB_DIR=`dirname $i`
	    SUB_DIR=${SUB_DIR##*/}
	    mkdir -p %{buildroot}%{_mandir}/ja/$SUB_DIR
	    install -m 644 $i %{buildroot}%{_mandir}/ja/$SUB_DIR
	done
done
cd %{buildroot}%{_mandir}/ja
for i in */* ; do
    if [ -e %{_mandir}/ja/$i ] || [ -e %{_mandir}/ja/$i.gz ] ; then
	echo %{_mandir}/ja/$i already exists. Deleting it.
        rm -f $i
    fi
done
%fdupes -s %{buildroot}/%{_prefix}

%files
%{_mandir}/ja
%doc README

%changelog
* Thu Aug 24 2023 pgajdos@suse.com
- version update to 20230815
  * no upstream changelog
* Fri Jun 23 2023 pgajdos@suse.com
- version update to 20230615
  * Improved and updated manual pages
* Fri Jan 20 2023 Dirk Müller <dmueller@suse.com>
- update to version 20230115
  * Improved and updated manual pages
* Tue Dec 27 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 20221215
  * Improved and updated manual pages
* Sun Dec  4 2022 Dirk Müller <dmueller@suse.com>
- update to release 20221015
  * Improved manual pages
* Mon Aug 29 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20220815
  * Improved manual pages
* Tue May 10 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 20220415
  * Added and improved manual pages
* Mon Dec 13 2021 pgajdos@suse.com
- version update to 20211115
  * added and improved manual pages
* Wed Jul 21 2021 Callum Farmer <gmbr3@opensuse.org>
- Remove conflicting cdparanoia manpage
* Sun Jun 27 2021 oota toshiya <ribbon@users.sourceforge.jp>
- update SPEC file
* Mon May 31 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 20210515
  * added and improved manual pages
* Mon Dec 28 2020 pgajdos@suse.com
- version update to 20201215
  * added and improved manual pages
* Fri Dec 11 2020 oota toshiya <ribbon@users.sourceforge.jp>
- version update to 20201115
  * added and improved manual pages
* Thu Dec 19 2019 pgajdos@suse.com
- version update to 20191215
  * added and improved manual pages
* Fri Dec 28 2018 Petr Gajdos <pgajdos@suse.com>
- update to 20181215
  * added and improved manual pages
* Mon Dec 18 2017 pgajdos@suse.com
- update to 20171215
  * added and improved manual pages
* Wed Jun 14 2017 tchvatal@suse.com
- Update to 20170515
  * added and improved manual pages
* Mon Nov 21 2016 pgajdos@suse.com
- update to 20161115
  * added and improved manual pages
* Wed Dec 16 2015 pgajdos@suse.com
- update to 20151215
  * added and improved manual pages
* Mon May 11 2015 pgajdos@suse.com
- update to 20150415
  * added and improved manual pages
* Tue Nov 18 2014 pgajdos@suse.com
- update to 20141115
  * added and improved manual pages
* Sun Oct 12 2014 jengelh@inai.de
- Update to new upstream release 20140915
  * No upstream changelog was provided
- Remove ancient specfile tags and sections
- Remove unneeded dependency "deb", has no effect on filelist
* Mon Jun 23 2014 pgajdos@suse.com
- updated to 20140615:
  * added and improved manual pages
* Mon Mar 31 2014 pgajdos@suse.com
- updated to 20140315:
  * added and improved manual pages
* Wed Nov 27 2013 pgajdos@suse.com
- updated to 20131115:
  * added and improved manual pages
* Tue Mar 26 2013 pgajdos@suse.com
- updated 20130315:
  * improved manual pages
* Fri Mar 30 2012 cfarrell@suse.com
- license update: GPL-2.0 and BSD-3-Clause and GFDL-1.1 and GFDL-1.2 and
  GFDL-1.3
  SPDX format for the aggregation
* Mon May 23 2011 pgajdos@novell.com
- updated to 20110515
  * improved manual pages
* Thu Aug 26 2010 pgajdos@suse.cz
- updated to 20100415
* Tue Nov 24 2009 pgajdos@suse.cz
- update to 20091115
- spec file cleanups
* Thu Jul  5 2007 lrupp@suse.de
- update to 20070615
- cleanup after build is finished
- use fdupes
* Tue Feb 28 2006 mfabian@suse.de
- add "Provides: locale(man:ja)".
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jul 25 2005 mfabian@suse.de
- update to 20050715.
* Sat Aug 21 2004 mfabian@suse.de
- update to 20040815.
* Mon Feb 23 2004 hmacht@suse.de
- building as non-root
* Thu Aug 21 2003 mfabian@suse.de
- update to 20030815.
* Tue Jan 21 2003 mfabian@suse.de
- update to 20030115.
* Sun Aug 18 2002 mfabian@suse.de
- update to 20020816.
* Wed Mar 13 2002 mfabian@suse.de
- update to 20020215.
- build manually again because the sources are only available
  via http://
* Sat Apr  7 2001 mfabian@suse.de
- add deb and cdparanoia to "# neededforbuild"
* Fri Mar 23 2001 mfabian@suse.de
- remove "nearlyall" from "# neededforbuild"
  it causes too much problems and in consequence this packages
  rarely ever builds.
  The reason for the "nearlyall" in "# neededforbuild" is only
  to check a SuSE system with everything installed for Japanese
  man-pages and remove duplicates. But currently only very few
  Japanese man-pages outside of man-pages-ja exist, so this
  sort of overkill. It should be enough to include all these
  other packages containing  Japanese man-pages into the
  "# neededforbuild".
* Mon Nov 27 2000 mfabian@suse.de
- renamed to man-pages-ja
* Fri Sep  8 2000 mfabian@suse.de
- updated to new version man-pages-ja-20000815.tar.gz.
  The new tar-ball contains a different directory structure,
  therefore the old script didn't work anymore.
  On top of that the new tar-ball contains duplicate man-pages,
  therefore I added some 'rm -f' to the specfile to remove the
  duplicates and keep only the 'best' version.
- used %%{_mandir} instead of /usr/share/man
* Fri Aug 11 2000 mfabian@suse.de
- new package ldpmanja, spec file based on ldpmande
